(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     24089,        843]
NotebookOptionsPosition[     20292,        709]
NotebookOutlinePosition[     20780,        728]
CellTagsIndexPosition[     20737,        725]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Impedance Routing", "Title"],

Cell[CellGroupData[{

Cell["Board Parameters", "Section"],

Cell["All units in mils", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Boardthickness", "=", "62"}], ";", "  ", 
   RowBox[{"(*", " ", "mil", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Copper", "=", "1.0"}], ";"}], "                    ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"oz", "/", "sq"}], " ", "inch"}], ";", " ", 
    RowBox[{
     RowBox[{"1", "oz"}], " ", "=", " ", 
     RowBox[{"1.4", "mil"}]}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Corethickness", "=", "39"}], ";"}], "    ", 
  RowBox[{"(*", " ", "mil", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Prepregthickness", "=", "8.7"}], ";", "     ", 
  RowBox[{"(*", " ", "mil", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Er", "=", "4.2"}], ";", "                           ", 
  RowBox[{"(*", " ", 
   RowBox[{"dielectric", " ", "constant"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Layers", "=", "4"}], ";", "                     ", 
  RowBox[{"(*", "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"rule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"planethickness", "\[Rule]", "Prepregthickness"}], ",", 
     RowBox[{"planeplane", "\[Rule]", 
      RowBox[{
      "Corethickness", "+", "Prepregthickness", "+", "traceheight"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"corethickness", "\[Rule]", "Corethickness"}], ",", 
     RowBox[{"prepregthickness", "\[Rule]", "Prepregthickness"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"boardthickness", "\[Rule]", "Boardthickness"}], ",", 
     RowBox[{"er", "\[Rule]", "Er"}], ",", 
     RowBox[{"layers", "\[Rule]", "Layers"}], ",", 
     RowBox[{"copper", "\[Rule]", "Copper"}], ",", 
     RowBox[{"traceheight", "\[Rule]", 
      RowBox[{"copper", "*", "1.4"}]}]}], "}"}]}], ";", 
  "\[IndentingNewLine]"}]}], "Input",
 CellChangeTimes->{{3.429617748753625*^9, 3.429617801691125*^9}, {
  3.4353354197898474`*^9, 3.4353354790554724`*^9}}],

Cell["\<\
Check board thickness from build-up\
\>", "Text",
 CellChangeTimes->{{3.429617765347375*^9, 3.429617769113*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"layers", "*", "traceheight"}], "+", 
   RowBox[{
    FractionBox["layers", "2"], "*", "prepregthickness"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["layers", "2"], "-", "1"}], ")"}], "*", "corethickness"}]}],
   "//.", "rule"}]], "Input"],

Cell[BoxData["62.`"], "Output",
 CellChangeTimes->{{3.429617770909875*^9, 3.4296178050505*^9}, {
  3.4353354433992224`*^9, 3.4353354811648474`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Microstrip", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Zm", "[", "w_", "]"}], ":=", 
  RowBox[{
   FractionBox["87", 
    SqrtBox[
     RowBox[{"er", "+", "1.41"}]]], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"5.98", "planethickness"}], 
     RowBox[{
      RowBox[{"0.8", "w"}], "+", "traceheight"}]], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Speedm", ":=", 
  RowBox[{
   FractionBox["1", "12"], "1.017", 
   SqrtBox[
    RowBox[{
     RowBox[{"0.475", "er"}], "+", "0.67"}]], "     ", 
   RowBox[{"(*", " ", 
    RowBox[{"in", " ", 
     RowBox[{"ns", "/", "inch"}]}], " ", "*)"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Zm", "[", "9", "]"}], "//.", "rule"}]], "Input"],

Cell[BoxData["66.11588826365568`"], "Output",
 CellChangeTimes->{3.429617809534875*^9, 3.4353355104929724`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Zm", "[", "w", "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "50"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     RowBox[{"7.4750000000000005`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.011494252873563218`"}], " ", 
        SqrtBox[
         RowBox[{"1.41`", "\[InvisibleSpace]", "+", 
          RowBox[{"1.`", " ", "er"}]}]], " ", "Z0"}]], " ", 
      SuperscriptBox["planethickness", 
       "0.99999999999999999999999999991`15.906029430411715"]}], "-", 
     RowBox[{"1.25`", " ", "traceheight"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429617809816125*^9, 3.4353355107117224`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "14.920739276842799`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429617809816125*^9, 3.4353355107117224`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Speedm", "//.", "rule"}]], "Input"],

Cell[BoxData["0.13835291490424043`"], "Output",
 CellChangeTimes->{3.429617809847375*^9, 3.4353355107429724`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential Microstrip", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZmDiff", "[", 
   RowBox[{"w_", ",", "s_"}], "]"}], ":=", 
  RowBox[{"2", 
   RowBox[{"Zm", "[", "w", "]"}], 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"0.48", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "0.96"}], " ", 
        FractionBox["s", "planethickness"]}], "]"}]}]}], ")"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ZmDiff", "[", 
   RowBox[{"10", ",", "8"}], "]"}], "//.", "rule"}]], "Input",
 CellChangeTimes->{{3.4353355955867224`*^9, 3.4353356333367224`*^9}}],

Cell[BoxData["100.7405495925305`"], "Output",
 CellChangeTimes->{
  3.429617927597375*^9, 3.4353355146179724`*^9, {3.4353355966648474`*^9, 
   3.4353356337742224`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ZmDiff", "[", 
      RowBox[{"w", ",", "8"}], "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "100"}]}], "//.", "rule"}]}], "Input",
 CellChangeTimes->{{3.4353356277117224`*^9, 3.4353356278367224`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     RowBox[{"7.4750000000000005`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"25.`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"7.68`", "/", "planethickness"}]], " ", 
         SqrtBox[
          RowBox[{"1.41`", "\[InvisibleSpace]", "+", 
           RowBox[{"1.`", " ", "er"}]}]], " ", "Z0"}], 
        RowBox[{"2088.`", "\[InvisibleSpace]", "-", 
         RowBox[{"4350.`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"7.68`", "/", "planethickness"}]]}]}]]], " ", 
      "planethickness"}], "-", 
     RowBox[{"1.25`", " ", "traceheight"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429617927784875*^9, 3.4353355148210974`*^9, 
  3.4353356282117224`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "10.148723786606553`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429617927784875*^9, 3.4353355148210974`*^9, 
  3.4353356282273474`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stripline", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Z", "[", "w_", "]"}], ":=", 
  RowBox[{
   FractionBox["60", 
    SqrtBox["er"]], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"4", " ", "planeplane"}], 
     RowBox[{"0.67", "\[Pi]", " ", "w", 
      RowBox[{"(", 
       RowBox[{"0.8", "+", 
        RowBox[{"traceheight", "/", "w"}]}], ")"}]}]], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Speed", ":=", 
  RowBox[{
   RowBox[{"1", "/", "12"}], " ", "1.017", 
   SqrtBox["Er"], "      ", 
   RowBox[{"(*", " ", 
    RowBox[{"in", " ", 
     RowBox[{"ns", "/", "inch"}]}], " ", "*)"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Z", "[", "5", "]"}], "//.", "rule"}], "//", "N"}]], "Input"],

Cell[BoxData["83.4248798939461`"], "Output",
 CellChangeTimes->{{3.42961798026925*^9, 3.42961798908175*^9}, 
   3.4353355478992224`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Z", "[", "w", "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "50"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "::", "\<\"ifun\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Inverse functions are being used by \\!\\(Solve\\), so \
some solutions may not be found; use Reduce for complete solution \
information. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/Solve/ifun\\\", ButtonNote -> \
\\\"Solve::ifun\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.42961798064425*^9, 3.42961798914425*^9}, 
   3.4353355483679724`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{"1.25`", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1.9003575294554667`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "0.016666666666666666`"}], " ", 
           SqrtBox["er"], " ", "Z0"}]], " ", 
         SuperscriptBox["planeplane", "1.`"]}], "-", 
        RowBox[{"1.`", " ", "traceheight"}]}], ")"}], 
      "1.`15.954589770191005"]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.4296179806755*^9, 3.42961798914425*^9}, 
   3.4353355483835974`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "19.39111029942516`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.4296179806755*^9, 3.42961798914425*^9}, 
   3.4353355484304724`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Speed", "//.", "rule", "                       ", 
  RowBox[{"(*", " ", 
   RowBox[{"ns", "/", "inch"}], " ", "*)"}]}]], "Input"],

Cell[BoxData["0.1736858154830152`"], "Output",
 CellChangeTimes->{{3.429617980722375*^9, 3.429617989191125*^9}, 
   3.4353355484773474`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential Stripline", "Section"],

Cell["\<\
w: width, s: separation (mil)
result in Ohms\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZDiff", "[", 
   RowBox[{"w_", ",", "s_"}], "]"}], ":=", 
  RowBox[{"2", 
   RowBox[{"Z", "[", "w", "]"}], 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"0.347", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "2.9"}], " ", 
        FractionBox["s", "planeplane"]}], "]"}]}]}], ")"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ZDiff", "[", 
   RowBox[{"5", ",", "8"}], "]"}], "//.", "rule"}]], "Input"],

Cell[BoxData["130.75462178809602`"], "Output",
 CellChangeTimes->{3.429617995128625*^9, 3.4353355513679724`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ZDiff", "[", 
      RowBox[{"w", ",", "8"}], "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "100"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     RowBox[{"2.375446911819333`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"25.`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"23.2`", "/", "planeplane"}]], " ", 
         SqrtBox["er"], " ", "Z0"}], 
        RowBox[{"1041.`", "\[InvisibleSpace]", "-", 
         RowBox[{"3000.`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"23.2`", "/", "planeplane"}]]}]}]]], " ", "planeplane"}], 
     "-", 
     RowBox[{"1.25`", " ", "traceheight"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429617995284875*^9, 3.4353355515554724`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "11.444104927190923`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429617995284875*^9, 3.4353355515710974`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dual Stripline", "Section"],

Cell[TextData[{
 "stacked on top between to planes\nlayer model: prepreg + core + prepreg\n\
conditions: 0.1 < ",
 Cell[BoxData[
  FormBox[
   FractionBox["w", "prepregthickness"], TraditionalForm]]],
 " < 2.0 and ",
 Cell[BoxData[
  FormBox[
   FractionBox["traceheight", "prepregthickness"], TraditionalForm]]],
 "< 0.25\nw: width"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZDual", "[", "w_", "]"}], ":=", 
  RowBox[{
   FractionBox["80", 
    SqrtBox["er"]], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"1.9", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", "prepregthickness"}], "+", "traceheight"}], ")"}]}],
      
     RowBox[{
      RowBox[{"0.8", " ", "w"}], "+", "traceheight"}]], "]"}], 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox["prepregthickness", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
        "prepregthickness", "+", "corethickness", "+", "traceheight"}], 
        ")"}]}]]}], ")"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpeedDual", "=", 
  RowBox[{
   FractionBox["1", "12"], "1.017", 
   SqrtBox["er"], "     ", 
   RowBox[{"(*", " ", 
    RowBox[{"in", " ", 
     RowBox[{"ns", "/", "inch"}]}], " ", "*)"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"0.08474999999999999`", " ", 
  SqrtBox["er"]}]], "Output",
 CellChangeTimes->{3.429618155909875*^9, 3.4353355534460974`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ZDual", "[", "6", "]"}], "//.", "rule"}]], "Input"],

Cell[BoxData["65.33025036638205`"], "Output",
 CellChangeTimes->{3.429618155941125*^9, 3.4353355534929724`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ZDual", "[", "w", "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], 
  "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "50"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"1.`", " ", 
         SqrtBox["er"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1.`", " ", "corethickness"}], "+", 
           RowBox[{"1.`", " ", "prepregthickness"}], "+", 
           RowBox[{"1.`", " ", "traceheight"}]}], ")"}], " ", "Z0"}], 
        RowBox[{
         RowBox[{"80.`", " ", "corethickness"}], "+", 
         RowBox[{"60.`", " ", "prepregthickness"}], "+", 
         RowBox[{"80.`", " ", "traceheight"}]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4.75`", " ", "prepregthickness"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2.375`", "\[InvisibleSpace]", "-", 
          RowBox[{"1.25`", " ", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{
              SqrtBox["er"], " ", 
              RowBox[{"(", 
               RowBox[{
               "corethickness", "+", "prepregthickness", "+", "traceheight"}],
                ")"}], " ", "Z0"}], 
             RowBox[{
              RowBox[{"80.`", " ", "corethickness"}], "+", 
              RowBox[{"60.`", " ", "prepregthickness"}], "+", 
              RowBox[{"80.`", " ", "traceheight"}]}]]]}]}], ")"}], " ", 
        "traceheight"}]}], ")"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429618156128625*^9, 3.4353355536648474`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "9.938628826717316`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429618156128625*^9, 3.4353355536960974`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpeedDual", "//.", "rule", "                       ", 
  RowBox[{"(*", " ", 
   RowBox[{"ns", "/", "inch"}], " ", "*)"}]}]], "Input"],

Cell[BoxData["0.1736858154830152`"], "Output",
 CellChangeTimes->{3.429618156159875*^9, 3.4353355537585974`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Asymmetric Stripline", "Section"],

Cell[TextData[{
 "hhh: smaller layer thickness\nhhh1: greater layer thickness\n",
 "conditions: 0.1 < ",
 Cell[BoxData[
  FormBox[
   FractionBox["w", 
    RowBox[{"smaller", " ", "layer", " ", "thickness"}]], TraditionalForm]]],
 " < 2.0 and ",
 Cell[BoxData[
  FormBox[
   FractionBox["traceheight", 
    RowBox[{"smaller", " ", "layer", " ", "thickness"}]], TraditionalForm]]],
 "< 0.25"
}], "Text"],

Cell[BoxData[{
 RowBox[{"Off", "[", 
  RowBox[{"ReplaceAll", "::", "reps"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Za", "[", "w_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    FractionBox["80", 
     SqrtBox["er"]], 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"1.9", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", "hhh"}], "+", "traceheight"}], ")"}]}], 
      RowBox[{
       RowBox[{"0.8", " ", "w"}], "+", "traceheight"}]], "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["hhh", 
       RowBox[{"4", " ", "hhh1"}]]}], ")"}]}], "/.", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"prepregthickness", ">", "corethickness"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hhh", "\[Rule]", "corethickness"}], ",", 
       RowBox[{"hhh1", "\[Rule]", "prepregthickness"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hhh1", "\[Rule]", "corethickness"}], ",", 
       RowBox[{"hhh", "\[Rule]", "prepregthickness"}]}], "}"}]}], 
    "]"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Speeda", ":=", 
  RowBox[{
   FractionBox["1", "12"], " ", "1.017", 
   SqrtBox["Er"], "      ", 
   RowBox[{"(*", " ", 
    RowBox[{"in", " ", 
     RowBox[{"ns", "/", "inch"}]}], " ", "*)"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Za", "[", "5", "]"}], "//.", "rule"}], "//", "N"}]], "Input"],

Cell[BoxData["69.63813439834783`"], "Output",
 CellChangeTimes->{3.42961814808175*^9, 3.4353355555554724`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Za", "[", "w", "]"}], "//.", "rule"}], ")"}], "\[Equal]", 
     "Z0"}], ",", "w"}], "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "50"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "1.75`"}], "+", 
     RowBox[{"44.64999999999999`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.027130419543273887`"}], " ", "Z0"}]]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.429618148128625*^9, 3.4353355556179724`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "9.749842391160538`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429618148128625*^9, 3.4353355556179724`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Speeda", "//.", "rule", "                       ", 
  RowBox[{"(*", " ", 
   RowBox[{"ns", "/", "inch"}], " ", "*)"}]}]], "Input"],

Cell[BoxData["0.1736858154830152`"], "Output",
 CellChangeTimes->{3.429618148159875*^9, 3.4353355556648474`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{925, 1028},
WindowMargins->{{395, Automatic}, {9, Automatic}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 34, 0, 83, "Title"],
Cell[CellGroupData[{
Cell[649, 27, 35, 0, 71, "Section"],
Cell[687, 29, 33, 0, 29, "Text"],
Cell[723, 31, 1937, 44, 212, "Input"],
Cell[2663, 77, 122, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[2810, 84, 313, 10, 45, "Input"],
Cell[3126, 96, 148, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3323, 104, 29, 0, 71, "Section"],
Cell[3355, 106, 316, 11, 51, "Input"],
Cell[3674, 119, 278, 9, 45, "Input"],
Cell[CellGroupData[{
Cell[3977, 132, 83, 2, 31, "Input"],
Cell[4063, 136, 111, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4211, 142, 294, 9, 52, "Input"],
Cell[4508, 153, 618, 15, 42, "Output"],
Cell[5129, 170, 187, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5353, 179, 59, 1, 31, "Input"],
Cell[5415, 182, 113, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5577, 189, 42, 0, 71, "Section"],
Cell[5622, 191, 369, 12, 47, "Input"],
Cell[CellGroupData[{
Cell[6016, 207, 182, 4, 31, "Input"],
Cell[6201, 213, 168, 3, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6406, 221, 396, 11, 52, "Input"],
Cell[6805, 234, 844, 21, 55, "Output"],
Cell[7652, 257, 214, 5, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7915, 268, 28, 0, 71, "Section"],
Cell[7946, 270, 363, 12, 51, "Input"],
Cell[8312, 284, 232, 7, 34, "Input"],
Cell[CellGroupData[{
Cell[8569, 295, 107, 3, 31, "Input"],
Cell[8679, 300, 136, 2, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8852, 307, 293, 9, 52, "Input"],
Cell[9148, 318, 540, 11, 21, "Message"],
Cell[9691, 331, 628, 17, 47, "Output"],
Cell[10322, 350, 211, 5, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10570, 360, 153, 3, 31, "Input"],
Cell[10726, 365, 140, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10915, 373, 41, 0, 71, "Section"],
Cell[10959, 375, 68, 3, 47, "Text"],
Cell[11030, 380, 363, 12, 47, "Input"],
Cell[CellGroupData[{
Cell[11418, 396, 110, 3, 31, "Input"],
Cell[11531, 401, 112, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11680, 407, 325, 10, 52, "Input"],
Cell[12008, 419, 713, 18, 55, "Output"],
Cell[12724, 439, 187, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12960, 449, 33, 0, 71, "Section"],
Cell[12996, 451, 345, 11, 94, "Text"],
Cell[13344, 464, 638, 22, 51, "Input"],
Cell[CellGroupData[{
Cell[14007, 490, 227, 7, 45, "Input"],
Cell[14237, 499, 148, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14422, 507, 86, 2, 31, "Input"],
Cell[14511, 511, 111, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14659, 517, 297, 9, 52, "Input"],
Cell[14959, 528, 1500, 39, 115, "Output"],
Cell[16462, 569, 186, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16685, 578, 157, 3, 31, "Input"],
Cell[16845, 583, 112, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17006, 590, 39, 0, 71, "Section"],
Cell[17048, 592, 402, 13, 76, "Text"],
Cell[17453, 607, 1047, 32, 115, "Input"],
Cell[18503, 641, 231, 7, 45, "Input"],
Cell[CellGroupData[{
Cell[18759, 652, 108, 3, 31, "Input"],
Cell[18870, 657, 110, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19017, 663, 357, 11, 52, "Input"],
Cell[19377, 676, 380, 11, 33, "Output"],
Cell[19760, 689, 186, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19983, 698, 154, 3, 31, "Input"],
Cell[20140, 703, 112, 1, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
